summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/str71x
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/arch/arm/src/str71x')
-rw-r--r--nuttx/arch/arm/src/str71x/str71x_head.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/arch/arm/src/str71x/str71x_head.S b/nuttx/arch/arm/src/str71x/str71x_head.S
index 9965f8c69..72c08abcf 100644
--- a/nuttx/arch/arm/src/str71x/str71x_head.S
+++ b/nuttx/arch/arm/src/str71x/str71x_head.S
@@ -592,14 +592,14 @@ dtor_end:
* _sbss is the start of the BSS region (see ld.script)
* _ebss is the end of the BSS regsion (see ld.script)
* The idle task stack starts at the end of BSS and is
* of size CONFIG_PROC_STACK_SIZE. The heap continues
* from there until the end of memory. See g_heapbase
* below.
*/
LC0: .long _sbss
.long _ebss
- .long _ebss+CONFIG_PROC_STACK_SIZE-4
+ .long _ebss+CONFIG_IDLETHREAD_STACKSIZE-4
#ifdef CONFIG_BOOT_FROM_FLASH
LC2: .long _eronly /* Where .data defaults are stored in FLASH */
@@ -618,7 +618,7 @@ LC2: .long _eronly /* Where .data defaults are stored in FLASH */
.globl g_heapbase
.type g_heapbase, object
g_heapbase:
- .long _ebss+CONFIG_PROC_STACK_SIZE
+ .long _ebss+CONFIG_IDLETHREAD_STACKSIZE
.size g_heapbase, .-g_heapbase
.end
@@ -592,14 +592,14 @@ dtor_end:
* _ebss is the end of the BSS regsion (see ld.script)
* The idle task stack starts at the end of BSS and is
- * of size CONFIG_PROC_STACK_SIZE. The heap continues
+ * of size CONFIG_IDLETHREAD_STACKSIZE. The heap continues
* from there until the end of memory. See g_heapbase
* below.